@@ -204,9 +204,9 @@ def get_recmode_tuple(mode_name):
     Return a tuple (listno, sublistno), or (None, None) if
     not found.
     """
-    for i in range(0, len(Status.RECMODES)):
-        if mode_name in Status.RECMODES[i]:
-            return (i, Status.RECMODES[i].index(mode_name))
+    for i, modes in enumerate(Status.RECMODES):
+        if mode_name in modes:
+            return (i, modes.index(mode_name))
     return (None, None)
 
 
@@ -287,8 +287,8 @@ class Lighting1(Packet):
             self.packettype = 0x10
             self.subtype = subtype
             hcode = id_string[0:1]
-            for hcode_num in self.HOUSECODES:
-                if self.HOUSECODES[hcode_num] == hcode:
+            for hcode_num, hcode_code in self.HOUSECODES.items():
+                if hcode_code == hcode:
                     self.housecode = hcode_num
             self.unitcode = int(id_string[1:])
             self._set_strings()
@@ -1054,6 +1054,78 @@ class SensorPacket(Packet):
     """
 
 
+###############################################################################
+# Undecoded class
+###############################################################################
+
+class Undecoded(SensorPacket):
+    """
+    Data class for the Undecoded packet type
+    """
+
+    TYPES = {
+        0x00: 'ac',
+        0x01: 'arc',
+        0x02: 'ati',
+        0x03: 'hideki/upm',
+        0x04: 'lacrosse/viking',
+        0x05: 'ad',
+        0x06: 'mertik',
+        0x07: 'oregon1',
+        0x08: 'oregon2',
+        0x09: 'oregon3',
+        0x0A: 'proguard',
+        0x0B: 'visonic',
+        0x0C: 'nec',
+        0x0D: 'fs20',
+        0x0E: 'reserved',
+        0x0F: 'blinds',
+        0x10: 'rubicson',
+        0x11: 'ae',
+        0x12: 'fineoffset',
+        0x13: 'rgb',
+        0x14: 'rts',
+        0x15: 'selectplus',
+        0x16: 'homeconfort',
+        0x17: 'edisio',
+        0x18: 'honeywell',
+        0x19: 'funkbus',
+        0x1A: 'byronsx',
+    }
+    """
+    Mapping of numeric subtype values to strings, used in type_string
+    """
+
+    def __str__(self):
+        return ("Undecoded [subtype={0} payload={1}]").format(self.type_string,
+                                       self.payload)
+
+    def __init__(self):
+        """Constructor"""
+        super().__init__()
+        self.payload = None
+
+    def load_receive(self, data):
+        """Load data from a bytearray"""
+        self.data = data
+        self.packetlength = data[0]
+        self.packettype = data[1]
+
+        self.subtype = data[2]
+        self.payload = data[4:]
+
+        self._set_strings()
+
+    def _set_strings(self):
+        """Translate loaded numeric values into convenience strings"""
+        self.id_string = 'Undecoded'
+        if self.subtype in self.TYPES:
+            self.type_string = self.TYPES[self.subtype]
+        else:
+            # Degrade nicely for yet unknown subtypes
+            self.type_string = 'Unknown'
+
+
 ###############################################################################
 # Temp class
 ###############################################################################
@@ -1622,7 +1694,8 @@ class Rain(SensorPacket):
             # cartridge can be 0.01 inch rather than 0.2mm
             self.raintotal = 0.2 * self.raintotal3
         elif self.subtype == 9:
-            self.raintotal = 0.254 * self.raintotal3
+            self.raintotal = 0.254 * float((self.raintotal2 << 8) + 
+                                            self.raintotal3)
 
         self.rssi_byte = data[11]
         self.battery = self.rssi_byte & 0x0f
@@ -2159,8 +2232,10 @@ class Cartelectronic(SensorPacket):
         self.voltage = None
         self.currentwatt = None
         self.teleinfo_ok = None
+        self.state_byte = None
         self.battery = None
         self.rssi = None
+        self.contract_type = None
 
     def load_receive(self, data):
         """Load data from a bytearray"""
@@ -2175,7 +2250,18 @@ class Cartelectronic(SensorPacket):
         self.id4 = data[7]
         self.id_combined = ((self.id1 << 24) + (self.id2 << 16) +
                             (self.id3 << 8) + self.id4)
-        if self.subtype == 0x02:
+        if self.subtype == 0x01:
+            # TIC
+            self.id5 = data[8]
+            self.id_combined = (self.id_combined << 8) + self.id5
+            self.contract_type = data[9]
+            self.counter1 = int.from_bytes(data[10:14], 'big')
+            self.counter2 = int.from_bytes(data[14:18], 'big')
+            self.currentwatt = int.from_bytes(data[18:20], 'big')
+            self.state_byte = data[20]
+            self.teleinfo_ok = not (data[20] & 0x04) == 0x04
+            self.rssi_byte = data[17]
+        elif self.subtype == 0x02:
             # Cartelectronic Encoder
             self.counter1 = ((data[8] * pow(2, 24)) + (data[9] << 16) +
                              (data[10] << 8) + data[11])
@@ -2191,6 +2277,7 @@ class Cartelectronic(SensorPacket):
             self.tarif_num = (data[16] & 0x0f)
             self.voltage = data[17] + 200
             self.currentwatt = (data[18] << 8) + data[19]
+            self.state_byte = data[20]
             self.teleinfo_ok = not (data[20] & 0x04) == 0x04
             self.rssi_byte = data[21]
         self.battery = self.rssi_byte & 0x0f
@@ -2582,8 +2669,7 @@ class RollerTrol(Packet):
              0x04: 'BlindsT4 / Raex YR1326',
              0x05: 'BlindsT5 / Media Mount',
              0x06: 'BlindsT6 / DC106/Rohrmotor24-RMF/Yooda',
-             0x07: 'BlindsT7 / Forest'
-    }
+             0x07: 'BlindsT7 / Forest'}
     """
     Mapping of numeric subtype values to strings, used in type_string
     """
@@ -2695,6 +2781,7 @@ class RollerTrol(Packet):
 
 PACKET_TYPES = {
     0x01: Status,
+    0x03: Undecoded,
     0x10: Lighting1,
     0x11: Lighting2,
     0x12: Lighting3,
